qqpareto: QQ-plot for the Pareto distribution

View source: R/graph-qqpareto.R

qqparetoR Documentation

QQ-plot for the Pareto distribution

Description

Computes the empirical quantiles of the log-transform (since Pareto distribution = log-exponential distribution) of a data vector and the theoretical quantiles of the standard exponential distribution. These quantiles are then plotted in a Pareto QQ-plot with the theoretical quantiles on the x-axis and the empirical quantiles on the y-axis.

Usage

qqpareto(data, xlab, ylab, main="Pareto QQ-plot", 
doline=TRUE, line.col="blue", ...)

Arguments

data

A numeric vector.

xlab, ylab, main

graphical paramters, see plot.

doline

a logical to draw a line (obtained from least square).

line.col

a character for the line color.

...

Other arguments to plot.

Value

A list is invisibly returned with (x,y) values of points.

References

Coles, S. (2001) An Introduction to Statistical Modelling of Extreme Values. Springer Series in Statistics. London.

See Also

POT for the POT package, qqnorm for quantile-quantile plots.

Examples

data(ardieres)
ardieres <- clust(ardieres, 4, 10 / 365, clust.max = TRUE)
flows <- ardieres[, "obs"]
qqpareto(flows)

POT documentation built on Sept. 18, 2026, 9:11 a.m.