View source: R/graph-qqpareto.R
| qqpareto | R Documentation |
Computes the empirical quantiles of the log-transform (since Pareto distribution = log-exponential distribution) of a data vector and the theoretical quantiles of the standard exponential distribution. These quantiles are then plotted in a Pareto QQ-plot with the theoretical quantiles on the x-axis and the empirical quantiles on the y-axis.
qqpareto(data, xlab, ylab, main="Pareto QQ-plot",
doline=TRUE, line.col="blue", ...)
data |
A numeric vector. |
xlab, ylab, main |
graphical paramters, see |
doline |
a logical to draw a line (obtained from least square). |
line.col |
a character for the line color. |
... |
Other arguments to |
A list is invisibly returned with (x,y) values of points.
Coles, S. (2001) An Introduction to Statistical Modelling of Extreme Values. Springer Series in Statistics. London.
POT for the POT package, qqnorm for quantile-quantile plots.
data(ardieres)
ardieres <- clust(ardieres, 4, 10 / 365, clust.max = TRUE)
flows <- ardieres[, "obs"]
qqpareto(flows)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.