Computes the empirical quantiles of the log-transform (since Pareto distribution = log-exponential
distribution) of a data vector and the theoretical quantiles of the standard exponential distribution.
These quantiles are then plotted in a Pareto QQ-plot with the theoretical quantiles on the x-axis
and the empirical quantiles on the y-axis.